@@ -263,6 +263,12 @@ public class FormatData_hr extends ListResourceBundle {
             "d. M. y. G",
             "d. M. y. GGGGG",
         };
+        final String[] metaValue_japanese_DatePatterns = new String[] {
+            "EEEE, d. MMMM y. GGGG",
+            "d. MMMM y. GGGG",
+            "d. M. y. GGGG",
+            "d. M. y. G",
+        };
         final String metaValue_calendarname_gregorian = "gregorijanski kalendar";
         final String[] metaValue_ListPatterns_standard = new String[] {
             "",
@@ -514,14 +520,7 @@ public class FormatData_hr extends ListResourceBundle {
             { "japanese.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "japanese.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.japanese.DatePatterns", metaValue_java_time_japanese_DatePatterns },
-            { "japanese.DatePatterns",
-                new String[] {
-                    "EEEE, d. MMMM yyyy. GGGG",
-                    "d. MMMM yyyy. GGGG",
-                    "d. M. y. GGGG",
-                    "d. M. y. G",
-                }
-            },
+            { "japanese.DatePatterns", metaValue_japanese_DatePatterns },
             { "japanese.DateTimePatterns", metaValue_generic_DateTimePatterns },
             { "japanese.DateFormatItem.MMdd", metaValue_generic_DateFormatItem_MMdd },
             { "japanese.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
@@ -641,14 +640,7 @@ public class FormatData_hr extends ListResourceBundle {
             { "islamic.abbreviated.AmPmMarkers", metaValue_generic_narrow_AmPmMarkers },
             { "islamic.TimePatterns", metaValue_generic_TimePatterns },
             { "java.time.islamic.DatePatterns", metaValue_java_time_japanese_DatePatterns },
-            { "islamic.DatePatterns",
-                new String[] {
-                    "EEEE, d. MMMM y. GGGG",
-                    "d. MMMM y. GGGG",
-                    "d. M. y. GGGG",
-                    "d. M. y. G",
-                }
-            },
+            { "islamic.DatePatterns", metaValue_japanese_DatePatterns },
             { "islamic.DateFormatItem.MMdd", metaValue_generic_DateFormatItem_MMdd },
             { "islamic.DateFormatItem.hm", metaValue_generic_DateFormatItem_hm },
             { "islamic.DateFormatItem.yMMMEd", metaValue_generic_DateFormatItem_yMMMEd },
